@@ -3,6 +3,8 @@
 
 #include "spvm_native.h"
 
+#include <assert.h>
+
 #include "Eigen/Core"
 #include "Eigen/Dense"
 
@@ -20,8 +22,12 @@ int32_t SPVM__R__OP__Matrix__DoubleComplex___mul(SPVM_ENV* env, SPVM_VALUE* stac
   
   int32_t* ret_nrow_ref = stack[1].iref;
   
+  assert(ret_nrow_ref);
+  
   int32_t* ret_ncol_ref = stack[2].iref;
   
+  assert(ret_ncol_ref);
+  
   void* obj_x_data = stack[3].oval;
   std::complex<double>* x_data = (std::complex<double>*)env->get_elems_double(env, stack, obj_x_data);
   
@@ -67,8 +73,12 @@ int32_t SPVM__R__OP__Matrix__DoubleComplex___t(SPVM_ENV* env, SPVM_VALUE* stack)
   
   int32_t* ret_nrow_ref = stack[1].iref;
   
+  assert(ret_nrow_ref);
+  
   int32_t* ret_ncol_ref = stack[2].iref;
   
+  assert(ret_ncol_ref);
+  
   void* obj_x_data = stack[3].oval;
   std::complex<double>* x_data = (std::complex<double>*)env->get_elems_double(env, stack, obj_x_data);
   
@@ -107,8 +117,12 @@ int32_t SPVM__R__OP__Matrix__DoubleComplex___det(SPVM_ENV* env, SPVM_VALUE* stac
   
   int32_t* ret_nrow_ref = stack[1].iref;
   
+  assert(ret_nrow_ref);
+  
   int32_t* ret_ncol_ref = stack[2].iref;
   
+  assert(ret_ncol_ref);
+  
   void* obj_x_data = stack[3].oval;
   std::complex<double>* x_data = (std::complex<double>*)env->get_elems_double(env, stack, obj_x_data);
   
@@ -145,8 +159,12 @@ int32_t SPVM__R__OP__Matrix__DoubleComplex___solve(SPVM_ENV* env, SPVM_VALUE* st
   
   int32_t* ret_nrow_ref = stack[1].iref;
   
+  assert(ret_nrow_ref);
+  
   int32_t* ret_ncol_ref = stack[2].iref;
   
+  assert(ret_ncol_ref);
+  
   void* obj_x_data = stack[3].oval;
   std::complex<double>* x_data = (std::complex<double>*)env->get_elems_double(env, stack, obj_x_data);
   
@@ -183,14 +201,22 @@ int32_t SPVM__R__OP__Matrix__DoubleComplex___eigen(SPVM_ENV* env, SPVM_VALUE* st
   
   int32_t* eigen_vectors_nrow_ref = stack[1].iref;
   
+  assert(eigen_vectors_nrow_ref);
+  
   int32_t* eigen_vectors_ncol_ref = stack[2].iref;
   
+  assert(eigen_vectors_ncol_ref);
+  
   void* obj_eigen_values_data_ref = stack[3].oval;
   
   int32_t* eigen_values_nrow_ref = stack[4].iref;
   
+  assert(eigen_values_nrow_ref);
+  
   int32_t* eigen_values_ncol_ref = stack[5].iref;
   
+  assert(eigen_values_ncol_ref);
+  
   void* obj_x_data = stack[6].oval;
   std::complex<double>* x_data = (std::complex<double>*)env->get_elems_double(env, stack, obj_x_data);
   
